@@ -5,15 +5,21 @@ import pandas as pd
 import scipy.signal
 
 from ..epochs import epochs_create, epochs_to_df
-from ..signal import (signal_findpeaks, signal_formatpeaks, signal_resample,
-                      signal_smooth, signal_zerocrossings)
+from ..signal import (signal_findpeaks, signal_formatpeaks, signal_rate,
+                      signal_resample, signal_smooth, signal_zerocrossings)
 from ..stats import standardize
 from .ecg_peaks import ecg_peaks
 from .ecg_segment import ecg_segment
 
 
 def ecg_delineate(
-    ecg_cleaned, rpeaks=None, sampling_rate=1000, method="dwt", show=False, show_type="peaks", check=False
+    ecg_cleaned,
+    rpeaks=None,
+    sampling_rate=1000,
+    method="dwt",
+    show=False,
+    show_type="peaks",
+    check=False,
 ):
     """Delineate QRS complex.
 
@@ -45,6 +51,7 @@ def ecg_delineate(
         information.
     show_type: str
         The type of delineated waves information showed in the plot.
+        Can be "peaks", "bounds_R", "bounds_T", "bounds_P" or "all".
     check : bool
         Defaults to False. If True, replaces the delineated features with np.nan if its standardized distance
         from R-peaks is more than 3.
@@ -95,7 +102,10 @@ def ecg_delineate(
         if cols:
             ecg_cleaned = ecg_cleaned[cols[0]].values
         else:
-            raise ValueError("NeuroKit error: ecg_delineate(): Wrong input, we couldn't extract" "cleaned signal.")
+            raise ValueError(
+                "NeuroKit error: ecg_delineate(): Wrong input, we couldn't extract"
+                "cleaned signal."
+            )
 
     elif isinstance(ecg_cleaned, dict):
         for i in ecg_cleaned:
@@ -105,7 +115,10 @@ def ecg_delineate(
                 ecg_cleaned = signals[cols[0]].values
 
             else:
-                raise ValueError("NeuroKit error: ecg_delineate(): Wrong input, we couldn't extract" "cleaned signal.")
+                raise ValueError(
+                    "NeuroKit error: ecg_delineate(): Wrong input, we couldn't extract"
+                    "cleaned signal."
+                )
 
     # Sanitize input for rpeaks
     if rpeaks is None:
@@ -124,7 +137,9 @@ def ecg_delineate(
         waves = _dwt_ecg_delineator(ecg_cleaned, rpeaks, sampling_rate=sampling_rate)
 
     else:
-        raise ValueError("NeuroKit error: ecg_delineate(): 'method' should be one of 'peak'," "'cwt' or 'dwt'.")
+        raise ValueError(
+            "NeuroKit error: ecg_delineate(): 'method' should be one of 'peak'," "'cwt' or 'dwt'."
+        )
 
     # Remove NaN in Peaks, Onsets, and Offsets
     waves_noNA = waves.copy()
@@ -140,7 +155,11 @@ def ecg_delineate(
 
     if show is True:
         _ecg_delineate_plot(
-            ecg_cleaned, rpeaks=rpeaks, signals=signals, signal_features_type=show_type, sampling_rate=sampling_rate
+            ecg_cleaned,
+            rpeaks=rpeaks,
+            signals=signals,
+            signal_features_type=show_type,
+            sampling_rate=sampling_rate,
         )
 
     if check is True:
@@ -154,10 +173,10 @@ def ecg_delineate(
 # =============================================================================
 def _dwt_resample_points(peaks, sampling_rate, desired_sampling_rate):
     """Resample given points to a different sampling rate."""
-    if isinstance(peaks, np.ndarray):    # peaks are passed in from previous processing steps
+    if isinstance(peaks, np.ndarray):  # peaks are passed in from previous processing steps
         # Prevent overflow by converting to np.int64 (peaks might be passed in containing np.int32).
         peaks = peaks.astype(dtype=np.int64)
-    elif isinstance(peaks, list):    # peaks returned from internal functions
+    elif isinstance(peaks, list):  # peaks returned from internal functions
         # Cannot be converted to int since list might contain np.nan. Automatically cast to np.float64 if list contains np.nan.
         peaks = np.array(peaks)
     peaks_resample = peaks * desired_sampling_rate / sampling_rate
@@ -203,7 +222,9 @@ def _dwt_ecg_delineator(ecg, rpeaks, sampling_rate, analysis_sampling_rate=2000)
         speaks.append(S_index)
 
     # dwt to delineate tp waves, onsets, offsets and qrs ontsets and offsets
-    ecg = signal_resample(ecg, sampling_rate=sampling_rate, desired_sampling_rate=analysis_sampling_rate)
+    ecg = signal_resample(
+        ecg, sampling_rate=sampling_rate, desired_sampling_rate=analysis_sampling_rate
+    )
     dwtmatr = _dwt_compute_multiscales(ecg, 9)
 
     # # only for debugging
@@ -215,31 +236,63 @@ def _dwt_ecg_delineator(ecg, rpeaks, sampling_rate, analysis_sampling_rate=2000)
     # plt.show()
     rpeaks_resampled = _dwt_resample_points(rpeaks, sampling_rate, analysis_sampling_rate)
 
-    tpeaks, ppeaks = _dwt_delineate_tp_peaks(ecg, rpeaks_resampled, dwtmatr, sampling_rate=analysis_sampling_rate)
+    tpeaks, ppeaks = _dwt_delineate_tp_peaks(
+        ecg, rpeaks_resampled, dwtmatr, sampling_rate=analysis_sampling_rate
+    )
     qrs_onsets, qrs_offsets = _dwt_delineate_qrs_bounds(
         rpeaks_resampled, dwtmatr, ppeaks, tpeaks, sampling_rate=analysis_sampling_rate
     )
-    ponsets, poffsets = _dwt_delineate_tp_onsets_offsets(ppeaks, dwtmatr, sampling_rate=analysis_sampling_rate)
+    ponsets, poffsets = _dwt_delineate_tp_onsets_offsets(
+        ppeaks, rpeaks_resampled, dwtmatr, sampling_rate=analysis_sampling_rate
+    )
     tonsets, toffsets = _dwt_delineate_tp_onsets_offsets(
-        tpeaks, dwtmatr, sampling_rate=analysis_sampling_rate, onset_weight=0.6, duration=0.6
+        tpeaks,
+        rpeaks_resampled,
+        dwtmatr,
+        sampling_rate=analysis_sampling_rate,
+        onset_weight=0.6,
+        duration_onset=0.6,
     )
 
     return dict(
-        ECG_P_Peaks=_dwt_resample_points(ppeaks, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
-        ECG_P_Onsets=_dwt_resample_points(ponsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
-        ECG_P_Offsets=_dwt_resample_points(poffsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
+        ECG_P_Peaks=_dwt_resample_points(
+            ppeaks, analysis_sampling_rate, desired_sampling_rate=sampling_rate
+        ),
+        ECG_P_Onsets=_dwt_resample_points(
+            ponsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate
+        ),
+        ECG_P_Offsets=_dwt_resample_points(
+            poffsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate
+        ),
         ECG_Q_Peaks=qpeaks,
-        ECG_R_Onsets=_dwt_resample_points(qrs_onsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
-        ECG_R_Offsets=_dwt_resample_points(qrs_offsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
+        ECG_R_Onsets=_dwt_resample_points(
+            qrs_onsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate
+        ),
+        ECG_R_Offsets=_dwt_resample_points(
+            qrs_offsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate
+        ),
         ECG_S_Peaks=speaks,
-        ECG_T_Peaks=_dwt_resample_points(tpeaks, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
-        ECG_T_Onsets=_dwt_resample_points(tonsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
-        ECG_T_Offsets=_dwt_resample_points(toffsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
+        ECG_T_Peaks=_dwt_resample_points(
+            tpeaks, analysis_sampling_rate, desired_sampling_rate=sampling_rate
+        ),
+        ECG_T_Onsets=_dwt_resample_points(
+            tonsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate
+        ),
+        ECG_T_Offsets=_dwt_resample_points(
+            toffsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate
+        ),
     )
 
 
-def _dwt_compensate_degree(sampling_rate):
-    return int(np.log2(sampling_rate / 250))
+def _dwt_adjust_parameters(rpeaks, sampling_rate, duration=None, target=None):
+    average_rate = np.median(signal_rate(peaks=rpeaks, sampling_rate=sampling_rate))
+    if target == "degree":
+        # adjust defree of dwt by sampling_rate and HR
+        scale_factor = (sampling_rate / 250) / (average_rate / 60)
+        return int(np.log2(scale_factor))
+    elif target == "duration":
+        # adjust duration of search by HR
+        return np.round(duration * (60 / average_rate), 3)
 
 
 def _dwt_delineate_tp_peaks(
@@ -283,7 +336,14 @@ def _dwt_delineate_tp_peaks(
         Epsilon of RMS value of wavelet transform. Appendix (A.4).
     """
     srch_bndry = int(0.5 * qrs_width * sampling_rate)
-    degree_add = _dwt_compensate_degree(sampling_rate)
+    degree_add = _dwt_adjust_parameters(rpeaks, sampling_rate, target="degree")
+    # sanitize search duration by HR
+    p2r_duration = _dwt_adjust_parameters(
+        rpeaks, sampling_rate, duration=p2r_duration, target="duration"
+    )
+    rt_duration = _dwt_adjust_parameters(
+        rpeaks, sampling_rate, duration=rt_duration, target="duration"
+    )
 
     tpeaks = []
     for rpeak_ in rpeaks:
@@ -302,7 +362,9 @@ def _dwt_delineate_tp_peaks(
 
         ecg_local = ecg[srch_idx_start:srch_idx_end]
         peaks, __ = scipy.signal.find_peaks(np.abs(dwt_local), height=height)
-        peaks = list(filter(lambda p: np.abs(dwt_local[p]) > 0.025 * max(dwt_local), peaks))  # pylint: disable=W0640
+        peaks = list(
+            filter(lambda p: np.abs(dwt_local[p]) > 0.025 * max(dwt_local), peaks)
+        )  # pylint: disable=W0640
         if dwt_local[0] > 0:  # just append
             peaks = [0] + peaks
 
@@ -310,12 +372,18 @@ def _dwt_delineate_tp_peaks(
         candidate_peaks = []
         candidate_peaks_scores = []
         for idx_peak, idx_peak_nxt in zip(peaks[:-1], peaks[1:]):
-            correct_sign = dwt_local[idx_peak] > 0 and dwt_local[idx_peak_nxt] < 0  # pylint: disable=R1716
+            correct_sign = (
+                dwt_local[idx_peak] > 0 and dwt_local[idx_peak_nxt] < 0
+            )  # pylint: disable=R1716
             if correct_sign:
-                idx_zero = signal_zerocrossings(dwt_local[idx_peak:idx_peak_nxt+1])[0] + idx_peak
+                idx_zero = (
+                    signal_zerocrossings(dwt_local[idx_peak : idx_peak_nxt + 1])[0] + idx_peak
+                )
                 # This is the score assigned to each peak. The peak with the highest score will be
                 # selected.
-                score = ecg_local[idx_zero] - (float(idx_zero) / sampling_rate - (rt_duration - 0.5 * qrs_width))
+                score = ecg_local[idx_zero] - (
+                    float(idx_zero) / sampling_rate - (rt_duration - 0.5 * qrs_width)
+                )
                 candidate_peaks.append(idx_zero)
                 candidate_peaks_scores.append(score)
 
@@ -351,9 +419,13 @@ def _dwt_delineate_tp_peaks(
         candidate_peaks = []
         candidate_peaks_scores = []
         for idx_peak, idx_peak_nxt in zip(peaks[:-1], peaks[1:]):
-            correct_sign = dwt_local[idx_peak] > 0 and dwt_local[idx_peak_nxt] < 0  # pylint: disable=R1716
+            correct_sign = (
+                dwt_local[idx_peak] > 0 and dwt_local[idx_peak_nxt] < 0
+            )  # pylint: disable=R1716
             if correct_sign:
-                idx_zero = signal_zerocrossings(dwt_local[idx_peak:idx_peak_nxt+1])[0] + idx_peak
+                idx_zero = (
+                    signal_zerocrossings(dwt_local[idx_peak : idx_peak_nxt + 1])[0] + idx_peak
+                )
                 # This is the score assigned to each peak. The peak with the highest score will be
                 # selected.
                 score = ecg_local[idx_zero] - abs(
@@ -373,21 +445,29 @@ def _dwt_delineate_tp_peaks(
 
 def _dwt_delineate_tp_onsets_offsets(
     peaks,
+    rpeaks,
     dwtmatr,
     sampling_rate=250,
-    duration=0.3,
+    duration_onset=0.3,
     duration_offset=0.3,
     onset_weight=0.4,
     offset_weight=0.4,
     degree_onset=2,
     degree_offset=2,
 ):
-    degree = _dwt_compensate_degree(sampling_rate)
+    # sanitize search duration by HR
+    duration_onset = _dwt_adjust_parameters(
+        rpeaks, sampling_rate, duration=duration_onset, target="duration"
+    )
+    duration_offset = _dwt_adjust_parameters(
+        rpeaks, sampling_rate, duration=duration_offset, target="duration"
+    )
+    degree = _dwt_adjust_parameters(rpeaks, sampling_rate, target="degree")
     onsets = []
     offsets = []
     for i in range(len(peaks)):  # pylint: disable=C0200
         # look for onsets
-        srch_idx_start = peaks[i] - int(duration * sampling_rate)
+        srch_idx_start = peaks[i] - int(duration_onset * sampling_rate)
         srch_idx_end = peaks[i]
         if srch_idx_start is np.nan or srch_idx_end is np.nan:
             onsets.append(np.nan)
@@ -425,10 +505,12 @@ def _dwt_delineate_tp_onsets_offsets(
         if not (-dwt_local[offset_slope_peaks[0] :] < epsilon_offset).any():
             offsets.append(np.nan)
             continue
-        candidate_offsets = np.where(-dwt_local[offset_slope_peaks[0] :] < epsilon_offset)[0] + offset_slope_peaks[0]
+        candidate_offsets = (
+            np.where(-dwt_local[offset_slope_peaks[0] :] < epsilon_offset)[0]
+            + offset_slope_peaks[0]
+        )
         offsets.append(candidate_offsets[0] + srch_idx_start)
 
-
         # # only for debugging
         # events_plot([candidate_offsets, offset_slope_peaks], dwt_local)
         # plt.plot(ecg[srch_idx_start: srch_idx_end], '--', label='ecg')
@@ -438,7 +520,7 @@ def _dwt_delineate_tp_onsets_offsets(
 
 
 def _dwt_delineate_qrs_bounds(rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250):
-    degree = int(np.log2(sampling_rate / 250))
+    degree = _dwt_adjust_parameters(rpeaks, sampling_rate, target="degree")
     onsets = []
     for i in range(len(rpeaks)):  # pylint: disable=C0200
         # look for onsets
@@ -459,11 +541,12 @@ def _dwt_delineate_qrs_bounds(rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250
         candidate_onsets = np.where(-dwt_local[: onset_slope_peaks[-1]] < epsilon_onset)[0]
         onsets.append(candidate_onsets[-1] + srch_idx_start)
 
-        # # only for debugging
-        # events_plot(candidate_onsets, -dwt_local)
-        # plt.plot(ecg[srch_idx_start: srch_idx_end], '--', label='ecg')
-        # plt.legend()
-        # plt.show()
+        # only for debugging
+    #        import neurokit as nk
+    #        events_plot(candidate_onsets, -dwt_local)
+    #        plt.plot(ecg[srch_idx_start: srch_idx_end], '--', label='ecg')
+    #        plt.legend()
+    #        plt.show()
 
     offsets = []
     for i in range(len(rpeaks)):  # pylint: disable=C0200
@@ -482,7 +565,9 @@ def _dwt_delineate_qrs_bounds(rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250
         if not (dwt_local[onset_slope_peaks[0] :] < epsilon_offset).any():
             offsets.append(np.nan)
             continue
-        candidate_offsets = np.where(dwt_local[onset_slope_peaks[0] :] < epsilon_offset)[0] + onset_slope_peaks[0]
+        candidate_offsets = (
+            np.where(dwt_local[onset_slope_peaks[0] :] < epsilon_offset)[0] + onset_slope_peaks[0]
+        )
         offsets.append(candidate_offsets[0] + srch_idx_start)
 
         # # only for debugging
@@ -501,7 +586,13 @@ def _dwt_compute_multiscales(ecg: np.ndarray, max_degree):
         zeros = np.zeros(2 ** power - 1)
         timedelay = 2 ** power
         banks = np.r_[
-            1.0 / 8, zeros, 3.0 / 8, zeros, 3.0 / 8, zeros, 1.0 / 8,
+            1.0 / 8,
+            zeros,
+            3.0 / 8,
+            zeros,
+            3.0 / 8,
+            zeros,
+            1.0 / 8,
         ]
         signal_f = scipy.signal.convolve(signal_i, banks, mode="full")
         signal_f[:-timedelay] = signal_f[timedelay:]  # timeshift: 2 steps
@@ -535,13 +626,19 @@ def _ecg_delineator_cwt(ecg, rpeaks=None, sampling_rate=1000):
     tpeaks, ppeaks = _peaks_delineator(ecg, rpeaks, sampling_rate=sampling_rate)
 
     # qrs onsets and offsets
-    qrs_onsets, qrs_offsets = _onset_offset_delineator(ecg, rpeaks, peak_type="rpeaks", sampling_rate=sampling_rate)
+    qrs_onsets, qrs_offsets = _onset_offset_delineator(
+        ecg, rpeaks, peak_type="rpeaks", sampling_rate=sampling_rate
+    )
 
     # ppeaks onsets and offsets
-    p_onsets, p_offsets = _onset_offset_delineator(ecg, ppeaks, peak_type="ppeaks", sampling_rate=sampling_rate)
+    p_onsets, p_offsets = _onset_offset_delineator(
+        ecg, ppeaks, peak_type="ppeaks", sampling_rate=sampling_rate
+    )
 
     # tpeaks onsets and offsets
-    t_onsets, t_offsets = _onset_offset_delineator(ecg, tpeaks, peak_type="tpeaks", sampling_rate=sampling_rate)
+    t_onsets, t_offsets = _onset_offset_delineator(
+        ecg, tpeaks, peak_type="tpeaks", sampling_rate=sampling_rate
+    )
 
     # No dwt defined method for Q and S peak
     # Adopting manual method from "peak" method
@@ -604,14 +701,18 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
             search_window = cwtmatr[2, index_peak - half_wave_width : index_peak]
             prominence = 0.20 * max(search_window)
             height = 0.0
-            wt_peaks, wt_peaks_data = scipy.signal.find_peaks(search_window, height=height, prominence=prominence)
+            wt_peaks, wt_peaks_data = scipy.signal.find_peaks(
+                search_window, height=height, prominence=prominence
+            )
 
         elif peak_type in ["tpeaks", "ppeaks"]:
             search_window = -cwtmatr[4, index_peak - half_wave_width : index_peak]
 
             prominence = 0.10 * max(search_window)
             height = 0.0
-            wt_peaks, wt_peaks_data = scipy.signal.find_peaks(search_window, height=height, prominence=prominence)
+            wt_peaks, wt_peaks_data = scipy.signal.find_peaks(
+                search_window, height=height, prominence=prominence
+            )
 
         if len(wt_peaks) == 0:
             # print("Fail to find onset at index: %d", index_peak)
@@ -628,9 +729,13 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
                 epsilon_onset = 0.25 * wt_peaks_data["peak_heights"][-1]
             leftbase = wt_peaks_data["left_bases"][-1] + index_peak - half_wave_width
             if peak_type == "rpeaks":
-                candidate_onsets = np.where(cwtmatr[2, nfirst - 100 : nfirst] < epsilon_onset)[0] + nfirst - 100
+                candidate_onsets = (
+                    np.where(cwtmatr[2, nfirst - 100 : nfirst] < epsilon_onset)[0] + nfirst - 100
+                )
             elif peak_type in ["tpeaks", "ppeaks"]:
-                candidate_onsets = np.where(-cwtmatr[4, nfirst - 100 : nfirst] < epsilon_onset)[0] + nfirst - 100
+                candidate_onsets = (
+                    np.where(-cwtmatr[4, nfirst - 100 : nfirst] < epsilon_onset)[0] + nfirst - 100
+                )
 
             candidate_onsets = candidate_onsets.tolist() + [leftbase]
             if len(candidate_onsets) == 0:
@@ -642,12 +747,16 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
         if peak_type == "rpeaks":
             search_window = -cwtmatr[2, index_peak : index_peak + half_wave_width]
             prominence = 0.50 * max(search_window)
-            wt_peaks, wt_peaks_data = scipy.signal.find_peaks(search_window, height=height, prominence=prominence)
+            wt_peaks, wt_peaks_data = scipy.signal.find_peaks(
+                search_window, height=height, prominence=prominence
+            )
 
         elif peak_type in ["tpeaks", "ppeaks"]:
             search_window = cwtmatr[4, index_peak : index_peak + half_wave_width]
             prominence = 0.10 * max(search_window)
-            wt_peaks, wt_peaks_data = scipy.signal.find_peaks(search_window, height=height, prominence=prominence)
+            wt_peaks, wt_peaks_data = scipy.signal.find_peaks(
+                search_window, height=height, prominence=prominence
+            )
 
         if len(wt_peaks) == 0:
             # print("Fail to find offsets at index: %d", index_peak)
@@ -663,9 +772,13 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
                 epsilon_offset = 0.4 * wt_peaks_data["peak_heights"][0]
             rightbase = wt_peaks_data["right_bases"][0] + index_peak
             if peak_type == "rpeaks":
-                candidate_offsets = np.where((-cwtmatr[2, nlast : nlast + 100]) < epsilon_offset)[0] + nlast
+                candidate_offsets = (
+                    np.where((-cwtmatr[2, nlast : nlast + 100]) < epsilon_offset)[0] + nlast
+                )
             elif peak_type in ["tpeaks", "ppeaks"]:
-                candidate_offsets = np.where((cwtmatr[4, nlast : nlast + 100]) < epsilon_offset)[0] + nlast
+                candidate_offsets = (
+                    np.where((cwtmatr[4, nlast : nlast + 100]) < epsilon_offset)[0] + nlast
+                )
 
             candidate_offsets = candidate_offsets.tolist() + [rightbase]
             if len(candidate_offsets) == 0:
@@ -706,9 +819,13 @@ def _peaks_delineator(ecg, rpeaks, sampling_rate=1000):
         # set threshold for heights of peaks to find significant peaks in wavelet
         threshold = 0.125 * max(search_window)
         significant_peaks_tp = []
-        significant_peaks_tp = [peaks_tp[j] for j in range(len(peaks_tp)) if heights_tp["peak_heights"][j] > threshold]
+        significant_peaks_tp = [
+            peaks_tp[j] for j in range(len(peaks_tp)) if heights_tp["peak_heights"][j] > threshold
+        ]
 
-        significant_peaks_groups.append(_find_tppeaks(ecg, significant_peaks_tp, sampling_rate=sampling_rate))
+        significant_peaks_groups.append(
+            _find_tppeaks(ecg, significant_peaks_tp, sampling_rate=sampling_rate)
+        )
 
     tpeaks, ppeaks = zip(*[(g[0], g[-1]) for g in significant_peaks_groups])
 
@@ -733,13 +850,19 @@ def _find_tppeaks(ecg, keep_tp, sampling_rate=1000):
     tppeaks = []
     for index_cur, index_next in zip(keep_tp[:-1], keep_tp[1:]):
         # limit 1
-        correct_sign = cwtmatr[4, :][index_cur] < 0 and cwtmatr[4, :][index_next] > 0  # pylint: disable=R1716
+        correct_sign = (
+            cwtmatr[4, :][index_cur] < 0 and cwtmatr[4, :][index_next] > 0
+        )  # pylint: disable=R1716
         #    near = (index_next - index_cur) < max_wv_peak_dist #limit 2
         #    if near and correct_sign:
         if correct_sign:
-            index_zero_cr = signal_zerocrossings(cwtmatr[4, :][index_cur:index_next+1])[0] + index_cur
+            index_zero_cr = (
+                signal_zerocrossings(cwtmatr[4, :][index_cur : index_next + 1])[0] + index_cur
+            )
             nb_idx = int(max_search_duration * sampling_rate)
-            index_max = np.argmax(ecg[index_zero_cr - nb_idx : index_zero_cr + nb_idx]) + (index_zero_cr - nb_idx)
+            index_max = np.argmax(ecg[index_zero_cr - nb_idx : index_zero_cr + nb_idx]) + (
+                index_zero_cr - nb_idx
+            )
             tppeaks.append(index_max)
     if len(tppeaks) == 0:
         tppeaks = [np.nan]
@@ -810,7 +933,10 @@ def _ecg_delineator_peak(ecg, rpeaks=None, sampling_rate=1000):
 def _ecg_delineator_peak_Q(rpeak, heartbeat, R):
     segment = heartbeat[:0]  # Select left hand side
 
-    Q = signal_findpeaks(-1 * segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()))
+    Q = signal_findpeaks(
+        -1 * segment["Signal"],
+        height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()),
+    )
     if len(Q["Peaks"]) == 0:
         return np.nan, None
     Q = Q["Peaks"][-1]  # Select most right-hand side
@@ -823,7 +949,9 @@ def _ecg_delineator_peak_P(rpeak, heartbeat, R, Q):
         return np.nan, None
 
     segment = heartbeat.iloc[:Q]  # Select left of Q wave
-    P = signal_findpeaks(segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()))
+    P = signal_findpeaks(
+        segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min())
+    )
 
     if len(P["Peaks"]) == 0:
         return np.nan, None
@@ -834,7 +962,9 @@ def _ecg_delineator_peak_P(rpeak, heartbeat, R, Q):
 
 def _ecg_delineator_peak_S(rpeak, heartbeat):
     segment = heartbeat[0:]  # Select right hand side
-    S = signal_findpeaks(-segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()))
+    S = signal_findpeaks(
+        -segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min())
+    )
 
     if len(S["Peaks"]) == 0:
         return np.nan, None
@@ -847,7 +977,9 @@ def _ecg_delineator_peak_T(rpeak, heartbeat, R, S):
         return np.nan, None
 
     segment = heartbeat.iloc[R + S :]  # Select right of S wave
-    T = signal_findpeaks(segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()))
+    T = signal_findpeaks(
+        segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min())
+    )
 
     if len(T["Peaks"]) == 0:
         return np.nan, None
@@ -899,44 +1031,46 @@ def _ecg_delineator_peak_T_offset(rpeak, heartbeat, R, T):
 # =============================================================================
 
 
-def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_type="all", sampling_rate=1000):
+def _ecg_delineate_plot(
+    ecg_signal, rpeaks=None, signals=None, signal_features_type="all", sampling_rate=1000
+):
 
     """#    Examples.
 
-#    --------
-#    >>> import neurokit2 as nk
-#    >>> import numpy as np
-#    >>> import pandas as pd
-#    >>> import matplotlib.pyplot as plt
-#
-#    >>> ecg_signal = np.array(pd.read_csv(
-#    "https://raw.githubusercontent.com/neuropsychology/NeuroKit/dev/data/ecg_1000hz.csv"))[:, 1]
-#
-#    >>> # Extract R-peaks locations
-#    >>> _, rpeaks = nk.ecg_peaks(ecg_signal, sampling_rate=1000)
-#
-#    >>> # Delineate the ECG signal with ecg_delineate()
-#    >>> signals, waves = nk.ecg_delineate(ecg_signal, rpeaks, sampling_rate=1000)
-#
-#    >>> # Plot the ECG signal with markings on ECG peaks
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
-#                            signal_features_type='peaks', sampling_rate=1000)
-#
-#    >>> # Plot the ECG signal with markings on boundaries of R peaks
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
-#                            signal_features_type='bound_R', sampling_rate=1000)
-#
-#    >>> # Plot the ECG signal with markings on boundaries of P peaks
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
-#                            signal_features_type='bound_P', sampling_rate=1000)
-#
-#    >>> # Plot the ECG signal with markings on boundaries of T peaks
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
-#                            signal_features_type='bound_T', sampling_rate=1000)
-#
-#    >>> # Plot the ECG signal with markings on all peaks and boundaries
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
-#                            signal_features_type='all', sampling_rate=1000)
+    #    --------
+    #    >>> import neurokit2 as nk
+    #    >>> import numpy as np
+    #    >>> import pandas as pd
+    #    >>> import matplotlib.pyplot as plt
+    #
+    #    >>> ecg_signal = np.array(pd.read_csv(
+    #    "https://raw.githubusercontent.com/neuropsychology/NeuroKit/dev/data/ecg_1000hz.csv"))[:, 1]
+    #
+    #    >>> # Extract R-peaks locations
+    #    >>> _, rpeaks = nk.ecg_peaks(ecg_signal, sampling_rate=1000)
+    #
+    #    >>> # Delineate the ECG signal with ecg_delineate()
+    #    >>> signals, waves = nk.ecg_delineate(ecg_signal, rpeaks, sampling_rate=1000)
+    #
+    #    >>> # Plot the ECG signal with markings on ECG peaks
+    #    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+    #                            signal_features_type='peaks', sampling_rate=1000)
+    #
+    #    >>> # Plot the ECG signal with markings on boundaries of R peaks
+    #    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+    #                            signal_features_type='bound_R', sampling_rate=1000)
+    #
+    #    >>> # Plot the ECG signal with markings on boundaries of P peaks
+    #    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+    #                            signal_features_type='bound_P', sampling_rate=1000)
+    #
+    #    >>> # Plot the ECG signal with markings on boundaries of T peaks
+    #    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+    #                            signal_features_type='bound_T', sampling_rate=1000)
+    #
+    #    >>> # Plot the ECG signal with markings on all peaks and boundaries
+    #    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+    #                            signal_features_type='all', sampling_rate=1000)
 
     """
 
@@ -947,7 +1081,9 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
     if isinstance(rpeaks, dict):
         rpeaks = rpeaks["ECG_R_Peaks"]
     # Segment the signal around the R-peaks
-    epochs = epochs_create(data, events=rpeaks, sampling_rate=sampling_rate, epochs_start=-0.35, epochs_end=0.55)
+    epochs = epochs_create(
+        data, events=rpeaks, sampling_rate=sampling_rate, epochs_start=-0.35, epochs_end=0.55
+    )
     data = epochs_to_df(epochs)
     data_cols = data.columns.values
 
@@ -979,7 +1115,7 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
     data.Label = data.Label.astype(int)
     for label in data.Label.unique():
         epoch_data = data[data.Label == label]
-        ax.plot(epoch_data.Time, epoch_data.Signal, color="grey", alpha=0.2, label="_nolegend_")
+        ax.plot(epoch_data.Time, epoch_data.Signal, color="grey", alpha=0.2)
     for i, feature_type in enumerate(features.columns.values):  # pylint: disable=W0612
         event_data = data[data[feature_type] == 1.0]
         ax.scatter(event_data.Time, event_data.Signal, label=feature_type, alpha=0.5, s=200)
