@@ -5,10 +5,16 @@ import pandas as pd
 import scipy.signal
 import scipy.stats
 
-from ..signal import signal_findpeaks, signal_plot, signal_sanitize, signal_smooth, signal_zerocrossings
+from ..signal import (
+    signal_findpeaks,
+    signal_plot,
+    signal_sanitize,
+    signal_smooth,
+    signal_zerocrossings,
+)
 
 
-def ecg_findpeaks(ecg_cleaned, sampling_rate=1000, method="neurokit", show=False):
+def ecg_findpeaks(ecg_cleaned, sampling_rate=1000, method="neurokit", show=False, **kwargs):
     """Find R-peaks in an ECG signal.
 
     Low-level function used by `ecg_peaks()` to identify R-peaks in an ECG signal using a different
@@ -22,12 +28,13 @@ def ecg_findpeaks(ecg_cleaned, sampling_rate=1000, method="neurokit", show=False
         The sampling frequency of `ecg_signal` (in Hz, i.e., samples/second).
         Defaults to 1000.
     method : string
-        The algorithm to be used for R-peak detection. Can be one of 'neurokit' (default),
-        'pantompkins1985', 'hamilton2002', 'christov2004', 'gamboa2008', 'elgendi2010', 'engzeemod2012',
-        'kalidas2017', 'martinez2003', 'rodrigues2021' or 'promac'.
+        The algorithm to be used for R-peak detection. For a list of acceptable methods,
+        please refer to the documentation of `ecg_peaks`.
     show : bool
         If True, will return a plot to visualizing the thresholds used in the algorithm.
         Useful for debugging.
+    **kwargs
+        Additional keyword arguments, usually specific for each `method`.
 
     Returns
     -------
@@ -37,7 +44,7 @@ def ecg_findpeaks(ecg_cleaned, sampling_rate=1000, method="neurokit", show=False
 
     See Also
     --------
-    ecg_clean, signal_fixpeaks, ecg_peaks, ecg_rate, ecg_process, ecg_plot
+    ecg_peaks, ecg_clean, signal_fixpeaks, ecg_rate, ecg_process, ecg_plot
 
     Examples
     --------
@@ -91,74 +98,29 @@ def ecg_findpeaks(ecg_cleaned, sampling_rate=1000, method="neurokit", show=False
 
     References
     --------------
-    - Rodrigues, Tiago & Samoutphonh, Sirisack & Plácido da Silva, Hugo & Fred, Ana. (2021).
-      A Low-Complexity R-peak Detection Algorithm with Adaptive Thresholding for Wearable Devices.
-
-    - Gamboa, H. (2008). Multi-modal behavioral biometrics based on hci and electrophysiology.
-      PhD ThesisUniversidade.
-
-    - Zong, W., Heldt, T., Moody, G. B., & Mark, R. G. (2003). An open-source algorithm to
-      detect onset of arterial blood pressure pulses. In Computers in Cardiology, 2003 (pp. 259-262). IEEE.
-
-    - Hamilton, P. (2002, September). Open source ECG analysis. In Computers in cardiology (pp. 101-104). IEEE.
-
-    - Pan, J., & Tompkins, W. J. (1985). A real-time QRS detection algorithm. IEEE transactions on
-      biomedical engineering, (3), 230-236.
-
-    - Engelse, W. A. H., & Zeelenberg, C. (1979). A single scan algorithm for QRS detection and feature
-      extraction IEEE Comput Cardiol. Long Beach: IEEE Computer Society.
-
-    - Lourenço, A., Silva, H., Leite, P., Lourenço, R., & Fred, A. L. (2012). Real Time
-      Electrocardiogram Segmentation for Finger based ECG Biometrics. In Biosignals (pp. 49-54).
-
-    - Nabian, M., Yin, Y., Wormwood, J., Quigley, K. S., Barrett, L. F., Ostadabbas, S. (2018).
-      An Open-Source Feature Extraction Tool for the Analysis of Peripheral Physiological Data.
-      IEEE Journal of Translational Engineering in Health and Medicine, 6, 1-11. doi:10.1109/jtehm.2018.2878000
+    Please, see the list of references in the documentation of `ecg_peaks`.
 
     """
     # Try retrieving right column
     if isinstance(ecg_cleaned, pd.DataFrame):
         try:
             ecg_cleaned = ecg_cleaned["ECG_Clean"]
-        except NameError:
+        except (NameError, KeyError):
             try:
                 ecg_cleaned = ecg_cleaned["ECG_Raw"]
-            except NameError:
+            except (NameError, KeyError):
                 ecg_cleaned = ecg_cleaned["ECG"]
 
     # Sanitize input
     ecg_cleaned = signal_sanitize(ecg_cleaned)
-
     method = method.lower()  # remove capitalised letters
+
     # Run peak detection algorithm
-    if method in ["nk", "nk2", "neurokit", "neurokit2"]:
-        rpeaks = _ecg_findpeaks_neurokit(ecg_cleaned, sampling_rate, show=show)
-    elif method in ["pantompkins", "pantompkins1985"]:
-        rpeaks = _ecg_findpeaks_pantompkins(ecg_cleaned, sampling_rate)
-    elif method in ["nabian", "nabian2018"]:
-        rpeaks = _ecg_findpeaks_nabian2018(ecg_cleaned, sampling_rate)
-    elif method in ["gamboa2008", "gamboa"]:
-        rpeaks = _ecg_findpeaks_gamboa(ecg_cleaned, sampling_rate)
-    elif method in ["ssf", "slopesumfunction", "zong", "zong2003"]:
-        rpeaks = _ecg_findpeaks_ssf(ecg_cleaned, sampling_rate)
-    elif method in ["hamilton", "hamilton2002"]:
-        rpeaks = _ecg_findpeaks_hamilton(ecg_cleaned, sampling_rate)
-    elif method in ["christov", "christov2004"]:
-        rpeaks = _ecg_findpeaks_christov(ecg_cleaned, sampling_rate)
-    elif method in ["engzee", "engzee2012", "engzeemod", "engzeemod2012"]:
-        rpeaks = _ecg_findpeaks_engzee(ecg_cleaned, sampling_rate)
-    elif method in ["elgendi", "elgendi2010"]:
-        rpeaks = _ecg_findpeaks_elgendi(ecg_cleaned, sampling_rate)
-    elif method in ["kalidas2017", "swt", "kalidas", "kalidastamil", "kalidastamil2017"]:
-        rpeaks = _ecg_findpeaks_kalidas(ecg_cleaned, sampling_rate)
-    elif method in ["martinez2003", "martinez"]:
-        rpeaks = _ecg_findpeaks_WT(ecg_cleaned, sampling_rate)
-    elif method in ["rodrigues2020", "rodrigues2021", "rodrigues", "asi"]:
-        rpeaks = _ecg_findpeaks_rodrigues(ecg_cleaned, sampling_rate)
-    elif method in ["promac", "all"]:
-        rpeaks = _ecg_findpeaks_promac(ecg_cleaned, sampling_rate=sampling_rate, threshold=0.33, show=show)
-    else:
-        raise ValueError("NeuroKit error: ecg_findpeaks(): 'method' should be one of 'neurokit'" "or 'pantompkins'.")
+    try:
+        func = _ecg_findpeaks_findmethod(method)
+        rpeaks = func(ecg_cleaned, sampling_rate=sampling_rate, show=show, **kwargs)
+    except ValueError as error:
+        raise error
 
     # Prepare output.
     info = {"ECG_R_Peaks": rpeaks}
@@ -166,21 +128,111 @@ def ecg_findpeaks(ecg_cleaned, sampling_rate=1000, method="neurokit", show=False
     return info
 
 
+# Returns the peak detector function by name
+def _ecg_findpeaks_findmethod(method):
+    if method in ["nk", "nk2", "neurokit", "neurokit2"]:
+        return _ecg_findpeaks_neurokit
+    elif method in ["pantompkins", "pantompkins1985"]:
+        return _ecg_findpeaks_pantompkins
+    elif method in ["nabian", "nabian2018"]:
+        return _ecg_findpeaks_nabian2018
+    elif method in ["gamboa2008", "gamboa"]:
+        return _ecg_findpeaks_gamboa
+    elif method in ["ssf", "slopesumfunction", "zong", "zong2003"]:
+        return _ecg_findpeaks_ssf
+    elif method in ["hamilton", "hamilton2002"]:
+        return _ecg_findpeaks_hamilton
+    elif method in ["christov", "christov2004"]:
+        return _ecg_findpeaks_christov
+    elif method in ["engzee", "engzee2012", "engzeemod", "engzeemod2012"]:
+        return _ecg_findpeaks_engzee
+    elif method in ["elgendi", "elgendi2010"]:
+        return _ecg_findpeaks_elgendi
+    elif method in ["kalidas2017", "swt", "kalidas", "kalidastamil", "kalidastamil2017"]:
+        return _ecg_findpeaks_kalidas
+    elif method in ["martinez2003", "martinez"]:
+        return _ecg_findpeaks_WT
+    elif method in ["rodrigues2020", "rodrigues2021", "rodrigues", "asi"]:
+        return _ecg_findpeaks_rodrigues
+    elif method in ["promac", "all"]:
+        return _ecg_findpeaks_promac
+    else:
+        raise ValueError(f"NeuroKit error: ecg_findpeaks(): '{method}' not implemented.")
+
+
 # =============================================================================
 # Probabilistic Methods-Agreement via Convolution (ProMAC)
 # =============================================================================
-def _ecg_findpeaks_promac(signal, sampling_rate=1000, threshold=0.33, show=False, **kwargs):
+def _ecg_findpeaks_promac(
+    signal,
+    sampling_rate=1000,
+    show=False,
+    promac_methods=[
+        "neurokit",
+        "gamboa",
+        "ssf",
+        "engzee",
+        "elgendi",
+        "kalidas",
+        "martinez",
+        "rodrigues",
+    ],
+    threshold=0.33,
+    gaussian_sd=100,
+    **kwargs,
+):
+    """Probabilistic Methods-Agreement via Convolution (ProMAC).
 
+    ProMAC combines the result of several R-peak detectors in a probabilistic way. For a given peak
+    detector, the binary signal representing the peak locations is convolved with a Gaussian
+    distribution, resulting in a propabilistic representation of each peak location. This procedure
+    is repeated for all selected 'promac_methods' and the resulting signals are accumulated. Finally,
+    a threshold is used to accept or reject the peak locations.
+
+    See this discussion for more information on the origins of the method:
+    https://github.com/neuropsychology/NeuroKit/issues/222
+
+    Parameters
+    ----------
+    signal : Union[list, np.array, pd.Series]
+        The (cleaned) ECG channel, e.g. as returned by `ecg_clean()`.
+    sampling_rate : int
+        The sampling frequency of `ecg_signal` (in Hz, i.e., samples/second).
+        Defaults to 1000.
+    show : bool
+        If True, will return a plot to visualizing the thresholds used in the algorithm.
+        Useful for debugging.
+    promac_methods : list of string
+        The algorithms to be used for R-peak detection. See the list of acceptable algorithms for
+        the 'ecg_peaks' function.
+    threshold : float
+        The tolerance for peak acceptance. This value is a percentage of the signal's maximum
+        value. Only peaks found above this tolerance will be finally considered as actual peaks.
+    gaussian_sd : int
+        The standard deviation of the Gaussian distribution used to represent the peak location
+        probability. This value should be in millisencods and is usually taken as the size of
+        QRS complexes.
+
+    Returns
+    -------
+    rpeaks : list of int
+        A list of array positions at which R-peaks occur.
+
+    """
     x = np.zeros(len(signal))
+    promac_methods = [method.lower() for method in promac_methods]  # remove capitalised letters
+    error_list = []  # Stores the failed methods
 
-    x = _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, _ecg_findpeaks_neurokit, **kwargs)
-    x = _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, _ecg_findpeaks_gamboa, **kwargs)
-    x = _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, _ecg_findpeaks_ssf, **kwargs)
-    x = _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, _ecg_findpeaks_engzee, **kwargs)
-    x = _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, _ecg_findpeaks_elgendi, **kwargs)
-    x = _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, _ecg_findpeaks_kalidas, **kwargs)
-    x = _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, _ecg_findpeaks_WT, **kwargs)
-    x = _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, _ecg_findpeaks_rodrigues, **kwargs)
+    for method in promac_methods:
+        try:
+            func = _ecg_findpeaks_findmethod(method)
+            x = _ecg_findpeaks_promac_addconvolve(
+                signal, sampling_rate, x, func, gaussian_sd=gaussian_sd, **kwargs
+            )
+        except ValueError:
+            error_list.append(f"Method '{method}' is not valid.")
+        except Exception as error:
+            error_list.append(f"{method} error: {error}")
 
     # Rescale
     x = x / np.max(x)
@@ -193,26 +245,32 @@ def _ecg_findpeaks_promac(signal, sampling_rate=1000, threshold=0.33, show=False
 
     if show is True:
         signal_plot([signal, convoluted], standardize=True)
-        [plt.axvline(x=peak, color="red", linestyle="--") for peak in peaks]  # pylint: disable=W0106
+        [
+            plt.axvline(x=peak, color="red", linestyle="--") for peak in peaks
+        ]  # pylint: disable=W0106
+
+    # I am not sure if mandatory print the best option
+    if error_list:  # empty?
+        print(error_list)
 
     return peaks
 
 
-def _ecg_findpeaks_promac_addmethod(signal, sampling_rate, x, fun, **kwargs):
+# _ecg_findpeaks_promac_addmethod + _ecg_findpeaks_promac_convolve
+# Joining them makes parameters exposition more consistent
+def _ecg_findpeaks_promac_addconvolve(signal, sampling_rate, x, fun, gaussian_sd=100, **kwargs):
     peaks = fun(signal, sampling_rate=sampling_rate, **kwargs)
-    x += _ecg_findpeaks_promac_convolve(signal, peaks, sampling_rate=sampling_rate)
-    return x
 
+    mask = np.zeros(len(signal))
+    mask[peaks] = 1
 
-def _ecg_findpeaks_promac_convolve(signal, peaks, sampling_rate=1000):
-    x = np.zeros(len(signal))
-    x[peaks] = 1
-
-    # Because a typical QRS is roughly defined within about 100ms
-    sd = sampling_rate / 10
+    # SD is defined as a typical QRS size, which for adults if 100ms
+    sd = sampling_rate * gaussian_sd / 1000
     shape = scipy.stats.norm.pdf(np.linspace(-sd * 4, sd * 4, num=int(sd * 8)), loc=0, scale=sd)
 
-    return np.convolve(x, shape, "same")  # Return convolved
+    x += np.convolve(mask, shape, "same")
+
+    return x
 
 
 # =============================================================================
@@ -299,7 +357,7 @@ def _ecg_findpeaks_neurokit(
 # =============================================================================
 # Pan & Tompkins (1985)
 # =============================================================================
-def _ecg_findpeaks_pantompkins(signal, sampling_rate=1000):
+def _ecg_findpeaks_pantompkins(signal, sampling_rate=1000, **kwargs):
     """From https://github.com/berndporr/py-ecg-detectors/
 
     - Jiapu Pan and Willis J. Tompkins. A Real-Time QRS Detection Algorithm.
@@ -323,7 +381,7 @@ def _ecg_findpeaks_pantompkins(signal, sampling_rate=1000):
 # ===========================================================================
 # Nabian et al. (2018)
 # ===========================================================================
-def _ecg_findpeaks_nabian2018(signal, sampling_rate=1000):
+def _ecg_findpeaks_nabian2018(signal, sampling_rate=1000, **kwargs):
     """R peak detection method by Nabian et al. (2018) inspired by the Pan-Tompkins algorithm.
 
     - Nabian, M., Yin, Y., Wormwood, J., Quigley, K. S., Barrett, L. F., &amp; Ostadabbas, S. (2018).
@@ -353,7 +411,7 @@ def _ecg_findpeaks_nabian2018(signal, sampling_rate=1000):
 # =============================================================================
 # Hamilton (2002)
 # =============================================================================
-def _ecg_findpeaks_hamilton(signal, sampling_rate=1000):
+def _ecg_findpeaks_hamilton(signal, sampling_rate=1000, **kwargs):
     """From https://github.com/berndporr/py-ecg-detectors/
 
     - Hamilton, Open Source ECG Analysis Software Documentation, E.P.Limited, 2002.
@@ -385,7 +443,9 @@ def _ecg_findpeaks_hamilton(signal, sampling_rate=1000):
 
     for i in range(len(ma)):  # pylint: disable=C0200,R1702
 
-        if i > 0 and i < len(ma) - 1 and ma[i - 1] < ma[i] and ma[i + 1] < ma[i]:  # pylint: disable=R1716
+        if (
+            i > 0 and i < len(ma) - 1 and ma[i - 1] < ma[i] and ma[i + 1] < ma[i]
+        ):  # pylint: disable=R1716
             peak = i
             peaks.append(peak)
             if ma[peak] > th and (peak - QRS[-1]) > 0.3 * sampling_rate:
@@ -399,7 +459,10 @@ def _ecg_findpeaks_hamilton(signal, sampling_rate=1000):
                 if RR_ave != 0.0 and QRS[-1] - QRS[-2] > 1.5 * RR_ave:
                     missed_peaks = peaks[idx[-2] + 1 : idx[-1]]
                     for missed_peak in missed_peaks:
-                        if missed_peak - peaks[idx[-2]] > int(0.360 * sampling_rate) and ma[missed_peak] > 0.5 * th:
+                        if (
+                            missed_peak - peaks[idx[-2]] > int(0.36 * sampling_rate)
+                            and ma[missed_peak] > 0.5 * th
+                        ):
                             QRS.append(missed_peak)
                             QRS.sort()
                             break
@@ -429,7 +492,7 @@ def _ecg_findpeaks_hamilton(signal, sampling_rate=1000):
 # =============================================================================
 # Slope Sum Function (SSF) - Zong et al. (2003)
 # =============================================================================
-def _ecg_findpeaks_ssf(signal, sampling_rate=1000, threshold=20, before=0.03, after=0.01):
+def _ecg_findpeaks_ssf(signal, sampling_rate=1000, threshold=20, before=0.03, after=0.01, **kwargs):
     """From https://github.com/PIA-
     Group/BioSPPy/blob/e65da30f6379852ecb98f8e2e0c9b4b5175416c3/biosppy/signals/ecg.py#L448.
 
@@ -479,7 +542,7 @@ def _ecg_findpeaks_ssf(signal, sampling_rate=1000, threshold=20, before=0.03, af
 # =============================================================================
 # Christov (2004)
 # =============================================================================
-def _ecg_findpeaks_christov(signal, sampling_rate=1000):
+def _ecg_findpeaks_christov(signal, sampling_rate=1000, **kwargs):
     """From https://github.com/berndporr/py-ecg-detectors/
 
     - Ivaylo I. Christov, Real time electrocardiogram QRS detection using combined adaptive threshold,
@@ -611,7 +674,7 @@ def _ecg_findpeaks_christov(signal, sampling_rate=1000):
 # =============================================================================
 # Gamboa (2008)
 # =============================================================================
-def _ecg_findpeaks_gamboa(signal, sampling_rate=1000, tol=0.002):
+def _ecg_findpeaks_gamboa(signal, sampling_rate=1000, tol=0.002, **kwargs):
     """From https://github.com/PIA-
     Group/BioSPPy/blob/e65da30f6379852ecb98f8e2e0c9b4b5175416c3/biosppy/signals/ecg.py#L834.
 
@@ -656,7 +719,7 @@ def _ecg_findpeaks_gamboa(signal, sampling_rate=1000, tol=0.002):
 # =============================================================================
 # Engzee Modified (2012)
 # =============================================================================
-def _ecg_findpeaks_engzee(signal, sampling_rate=1000):
+def _ecg_findpeaks_engzee(signal, sampling_rate=1000, **kwargs):
     """From https://github.com/berndporr/py-ecg-detectors/
 
     - C. Zeelenberg, A single scan algorithm for QRS detection and feature extraction, IEEE Comp.
@@ -761,12 +824,19 @@ def _ecg_findpeaks_engzee(signal, sampling_rate=1000):
 
         if counter > neg_threshold:
             unfiltered_section = signal[thi_list[-1] - int(0.01 * sampling_rate) : i]
-            r_peaks.append(engzee_fake_delay + np.argmax(unfiltered_section) + thi_list[-1] - int(0.01 * sampling_rate))
+            r_peaks.append(
+                engzee_fake_delay
+                + np.argmax(unfiltered_section)
+                + thi_list[-1]
+                - int(0.01 * sampling_rate)
+            )
             counter = 0
             thi = False
             thf = False
 
-    r_peaks.pop(0)  # removing the 1st detection as it 1st needs the QRS complex amplitude for the threshold
+    r_peaks.pop(
+        0
+    )  # removing the 1st detection as it 1st needs the QRS complex amplitude for the threshold
     r_peaks = np.array(r_peaks, dtype="int")
     return r_peaks
 
@@ -774,7 +844,7 @@ def _ecg_findpeaks_engzee(signal, sampling_rate=1000):
 # =============================================================================
 # Stationary Wavelet Transform  (SWT) - Kalidas and Tamil (2017)
 # =============================================================================
-def _ecg_findpeaks_kalidas(signal, sampling_rate=1000):
+def _ecg_findpeaks_kalidas(signal, sampling_rate=1000, **kwargs):
     """From https://github.com/berndporr/py-ecg-detectors/
 
     - Vignesh Kalidas and Lakshman Tamil (2017). Real-time QRS detector using Stationary Wavelet Transform
@@ -811,11 +881,11 @@ def _ecg_findpeaks_kalidas(signal, sampling_rate=1000):
 
     squared = swt_ecg * swt_ecg
 
-    f1 = 0.01 / sampling_rate
-    f2 = 10 / sampling_rate
+    f1 = 0.01 / (0.5 * sampling_rate)
+    f2 = 10 / (0.5 * sampling_rate)
 
-    b, a = scipy.signal.butter(3, [f1 * 2, f2 * 2], btype="bandpass")
-    filtered_squared = scipy.signal.lfilter(b, a, squared)
+    sos = scipy.signal.butter(3, [f1, f2], btype="bandpass", output="sos")
+    filtered_squared = scipy.signal.sosfilt(sos, squared)
 
     # Drop padding to avoid detecting peaks inside it (#456)
     filtered_squared = filtered_squared[:signal_length]
@@ -829,7 +899,7 @@ def _ecg_findpeaks_kalidas(signal, sampling_rate=1000):
 # =============================================================================
 # Elgendi et al. (2010)
 # =============================================================================
-def _ecg_findpeaks_elgendi(signal, sampling_rate=1000):
+def _ecg_findpeaks_elgendi(signal, sampling_rate=1000, **kwargs):
     """From https://github.com/berndporr/py-ecg-detectors/
 
     - Elgendi, Mohamed & Jonkman, Mirjam & De Boer, Friso. (2010). Frequency Bands Effects on QRS Detection.
@@ -874,7 +944,7 @@ def _ecg_findpeaks_elgendi(signal, sampling_rate=1000):
 # Continuous Wavelet Transform (CWT) - Martinez et al. (2003)
 # =============================================================================
 #
-def _ecg_findpeaks_WT(signal, sampling_rate=1000):
+def _ecg_findpeaks_WT(signal, sampling_rate=1000, **kwargs):
     # Try loading pywt
     try:
         import pywt
@@ -940,7 +1010,7 @@ def _ecg_findpeaks_WT(signal, sampling_rate=1000):
 # =============================================================================
 
 
-def _ecg_findpeaks_rodrigues(signal, sampling_rate=1000):
+def _ecg_findpeaks_rodrigues(signal, sampling_rate=1000, **kwargs):
     """Segmenter by Tiago Rodrigues, inspired by on Gutierrez-Rivas (2015) and Sadhukhan (2012).
 
     References
@@ -1011,7 +1081,7 @@ def _ecg_findpeaks_rodrigues(signal, sampling_rate=1000):
 # =============================================================================
 
 
-def _ecg_findpeaks_MWA(signal, window_size):
+def _ecg_findpeaks_MWA(signal, window_size, **kwargs):
     """Based on https://github.com/berndporr/py-ecg-detectors/
 
     Optimized for vectorized computation.
@@ -1040,7 +1110,7 @@ def _ecg_findpeaks_MWA(signal, window_size):
     return mwa
 
 
-def _ecg_findpeaks_peakdetect(detection, sampling_rate=1000):
+def _ecg_findpeaks_peakdetect(detection, sampling_rate=1000, **kwargs):
     """Based on https://github.com/berndporr/py-ecg-detectors/
 
     Optimized for vectorized computation.
@@ -1079,7 +1149,8 @@ def _ecg_findpeaks_peakdetect(detection, sampling_rate=1000):
                 if peak - last_peak > RR_missed:
                     missed_peaks = peaks[last_index + 1 : index]
                     missed_peaks = missed_peaks[
-                        (missed_peaks > last_peak + min_missed_distance) & (missed_peaks < peak - min_missed_distance)
+                        (missed_peaks > last_peak + min_missed_distance)
+                        & (missed_peaks < peak - min_missed_distance)
                     ]
                     threshold_I2 = 0.5 * threshold_I1
                     missed_peaks = missed_peaks[detection[missed_peaks] > threshold_I2]
