@@ -14,14 +14,15 @@ def signal_psd(
     method="welch",
     show=False,
     normalize=True,
-    min_frequency=0,
+    min_frequency="default",
     max_frequency=np.inf,
     window=None,
-    window_type='hann',
+    window_type="hann",
     order=16,
     order_criteria="KIC",
     order_corrected=True,
-    **kwargs
+    silent=True,
+    **kwargs,
 ):
     """Compute the Power Spectral Density (PSD).
 
@@ -32,14 +33,16 @@ def signal_psd(
     sampling_rate : int
         The sampling frequency of the signal (in Hz, i.e., samples/second).
     method : str
-        Either 'multitapers' (default; requires the 'mne' package), or 'welch' (requires the 'scipy' package).
+        Either 'welch' (default), 'fft', 'multitapers' (requires the 'mne' package), 'lombscargle'
+        (requires the 'astropy' package) or 'burg'.
     show : bool
         If True, will return a plot. If False, will return the density values that can be plotted externally.
     normalize : bool
         Normalization of power by maximum PSD value. Default to True.
         Normalization allows comparison between different PSD methods.
-    min_frequency : float
-        The minimum frequency.
+    min_frequency : str, float
+        The minimum frequency. If "default", min_frequency is chosen based on the sampling rate and length of signal to
+        optimize the frequency resolution.
     max_frequency : float
         The maximum frequency.
     window : int
@@ -47,7 +50,7 @@ def signal_psd(
         calculated to capture at least 2 cycles of min_frequency. If the length of recording does not
         allow the formal, window will be default to half of the length of recording.
     window_type : str
-        Desired window to use. Defaults to 'hann'. See `scipy.signal.get_window()` for list of windows.
+        Desired window to use. Defaults to 'hann'. See ``scipy.signal.get_window()`` for list of windows.
     order : int
         The order of autoregression (only used for autoregressive (AR) methods such as 'burg').
     order_criteria : str
@@ -56,7 +59,9 @@ def signal_psd(
     order_corrected : bool
         Should the order criteria (AIC or KIC) be corrected? If unsure which method to use to choose
         the order, rely on the default (i.e., the corrected KIC).
-    **kwargs  : optional
+    silent : bool
+        If False, warnings will be printed. Default to True.
+    **kwargs : optional
         Keyword arguments to be passed to `scipy.signal.welch()`.
 
     See Also
@@ -73,31 +78,59 @@ def signal_psd(
     --------
     >>> import neurokit2 as nk
     >>>
-    >>> signal = nk.signal_simulate(frequency=5) + 0.5*nk.signal_simulate(frequency=20)
+    >>> signal = nk.signal_simulate(duration=2, frequency=[5, 6, 50, 52, 80], noise=0.5)
     >>>
-    >>> psd_multitapers = nk.signal_psd(signal, method="multitapers", show=True)
+    >>> # FFT method (based on numpy)
+    >>> psd_multitapers = nk.signal_psd(signal, method="fft", show=True)
+    >>> # Welch method (based on scipy)
     >>> psd_welch = nk.signal_psd(signal, method="welch", min_frequency=1, show=True)
+    >>> # Multitapers method (requires MNE)
+    >>> psd_multitapers = nk.signal_psd(signal, method="multitapers", show=True)
+    >>> # Burg method
     >>> psd_burg = nk.signal_psd(signal, method="burg", min_frequency=1, show=True)
+    >>> # Lomb method (requires AstroPy)
     >>> psd_lomb = nk.signal_psd(signal, method="lomb", min_frequency=1, show=True)
 
     """
     # Constant Detrend
     signal = signal - np.mean(signal)
 
-    # MNE
-    if method.lower() in ["multitapers", "mne"]:
-        frequency, power = _signal_psd_multitaper(
-                signal,
-                sampling_rate=sampling_rate,
-                min_frequency=min_frequency,
-                max_frequency=max_frequency,
-                normalize=normalize
-                )
+    # Sanitize method name
+    method = method.lower()
 
+    # Sanitize min_frequency
+    N = len(signal)
+    if isinstance(min_frequency, str):
+        min_frequency = (2 * sampling_rate) / (N / 2)  # for high frequency resolution
+
+    # MNE
+    if method in ["multitaper", "multitapers", "mne"]:
+        frequency, power = _signal_psd_multitaper(
+            signal,
+            sampling_rate=sampling_rate,
+            min_frequency=min_frequency,
+            max_frequency=max_frequency,
+        )
+
+    # FFT (Numpy)
+    elif method in ["fft"]:
+        frequency, power = _signal_psd_fft(signal, sampling_rate=sampling_rate)
+
+    # Lombscargle (AtroPy)
+    elif method.lower() in ["lombscargle", "lomb"]:
+        frequency, power = _signal_psd_lomb(
+            signal,
+            sampling_rate=sampling_rate,
+            min_frequency=min_frequency,
+            max_frequency=max_frequency,
+        )
+
+    # Method that are using a window
     else:
         # Define window length
         if min_frequency == 0:
-            min_frequency = 0.001  # sanitize lowest frequency
+            min_frequency = 0.001  # sanitize min_frequency
+
         if window is not None:
             nperseg = int(window * sampling_rate)
         else:
@@ -105,58 +138,55 @@ def signal_psd(
             nperseg = int((2 / min_frequency) * sampling_rate)
 
         # in case duration of recording is not sufficient
-        if nperseg > len(signal) / 2:
-            warn(
-                "The duration of recording is too short to support a"
-                " sufficiently long window for high frequency resolution."
-                " Consider using a longer recording or increasing the `min_frequency`",
-                category=NeuroKitWarning
-            )
-            nperseg = int(len(signal) / 2)
+        if nperseg > N / 2:
+            if silent is False:
+                warn(
+                    "The duration of recording is too short to support a"
+                    " sufficiently long window for high frequency resolution."
+                    " Consider using a longer recording or increasing the `min_frequency`",
+                    category=NeuroKitWarning,
+                )
+            nperseg = int(N / 2)
 
         # Welch (Scipy)
         if method.lower() in ["welch"]:
             frequency, power = _signal_psd_welch(
-                    signal,
-                    sampling_rate=sampling_rate,
-                    nperseg=nperseg,
-                    window_type=window_type,
-                    normalize=normalize,
-                    **kwargs
-            )
-
-        # Lombscargle (Scipy)
-        elif method.lower() in ["lombscargle", "lomb"]:
-            frequency, power = _signal_psd_lomb(
-                    signal,
-                    sampling_rate=sampling_rate,
-                    min_frequency=min_frequency,
-                    max_frequency=max_frequency,
-                    normalize=normalize
+                signal,
+                sampling_rate=sampling_rate,
+                nperseg=nperseg,
+                window_type=window_type,
+                **kwargs,
             )
 
         # BURG
         elif method.lower() in ["burg", "pburg", "spectrum"]:
             frequency, power = _signal_psd_burg(
-                    signal,
-                    sampling_rate=sampling_rate,
-                    order=order,
-                    criteria=order_criteria,
-                    corrected=order_corrected,
-                    side="one-sided",
-                    normalize=normalize,
-                    nperseg=nperseg
+                signal,
+                sampling_rate=sampling_rate,
+                order=order,
+                criteria=order_criteria,
+                corrected=order_corrected,
+                side="one-sided",
+                nperseg=nperseg,
             )
 
+    # Normalize
+    if normalize is True:
+        power /= np.max(power)
+
     # Store results
     data = pd.DataFrame({"Frequency": frequency, "Power": power})
 
     # Filter
-    data = data.loc[np.logical_and(data["Frequency"] >= min_frequency, data["Frequency"] <= max_frequency)]
-#    data["Power"] = 10 * np.log(data["Power"])
+    data = data.loc[
+        np.logical_and(data["Frequency"] >= min_frequency, data["Frequency"] <= max_frequency)
+    ]
+    #    data["Power"] = 10 * np.log(data["Power"])
 
     if show is True:
-        ax = data.plot(x="Frequency", y="Power", title="Power Spectral Density (" + str(method) + " method)")
+        ax = data.plot(
+            x="Frequency", y="Power", title="Power Spectral Density (" + str(method) + " method)"
+        )
         ax.set(xlabel="Frequency (Hz)", ylabel="Spectrum")
 
     return data
@@ -166,29 +196,39 @@ def signal_psd(
 # Multitaper method
 # =============================================================================
 
-def _signal_psd_multitaper(
-    signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf, normalize=True
-):
+
+def _signal_psd_fft(signal, sampling_rate=1000):
+    # Power-spectrum density (PSD)
+    power = np.abs(np.fft.rfft(signal)) ** 2
+    frequency = np.linspace(0, sampling_rate / 2, len(power))
+    return frequency, power
+
+
+# =============================================================================
+# Multitaper method
+# =============================================================================
+
+
+def _signal_psd_multitaper(signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf):
     try:
         import mne
-
-        power, frequency = mne.time_frequency.psd_array_multitaper(
-            signal,
-            sfreq=sampling_rate,
-            fmin=min_frequency,
-            fmax=max_frequency,
-            adaptive=True,
-            normalization="full",
-            verbose=False,
-        )
-    except ImportError:
+    except ImportError as e:
         raise ImportError(
             "NeuroKit error: signal_psd(): the 'mne'",
             " module is required for the 'mne' method to run.",
             " Please install it first (`pip install mne`).",
-        )
-    if normalize is True:
-        power /= np.max(power)
+        ) from e
+
+    power, frequency = mne.time_frequency.psd_array_multitaper(
+        signal,
+        sfreq=sampling_rate,
+        fmin=min_frequency,
+        fmax=max_frequency,
+        adaptive=True,
+        normalization="full",
+        verbose=False,
+    )
+
     return frequency, power
 
 
@@ -197,11 +237,9 @@ def _signal_psd_multitaper(
 # =============================================================================
 
 
-def _signal_psd_welch(
-    signal, sampling_rate=1000, nperseg=None, window_type='hann', normalize=True, **kwargs
-):
+def _signal_psd_welch(signal, sampling_rate=1000, nperseg=None, window_type="hann", **kwargs):
     if nperseg is not None:
-        nfft = int(nperseg*2)
+        nfft = int(nperseg * 2)
     else:
         nfft = None
 
@@ -214,11 +252,9 @@ def _signal_psd_welch(
         average="mean",
         nperseg=nperseg,
         window=window_type,
-        **kwargs
+        **kwargs,
     )
 
-    if normalize is True:
-        power /= np.max(power)
     return frequency, power
 
 
@@ -227,25 +263,24 @@ def _signal_psd_welch(
 # =============================================================================
 
 
-def _signal_psd_lomb(
-    signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf, normalize=True
-):
+def _signal_psd_lomb(signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf):
 
     try:
         import astropy.timeseries
+
         if max_frequency == np.inf:
             max_frequency = sampling_rate / 2  # sanitize highest frequency
         t = np.arange(len(signal)) / sampling_rate
-        frequency, power = astropy.timeseries.LombScargle(t, signal, normalization='psd').autopower(minimum_frequency=min_frequency, maximum_frequency=max_frequency)
+        frequency, power = astropy.timeseries.LombScargle(t, signal, normalization="psd").autopower(
+            minimum_frequency=min_frequency, maximum_frequency=max_frequency
+        )
 
-    except ImportError:
+    except ImportError as e:
         raise ImportError(
             "NeuroKit error: signal_psd(): the 'astropy'",
             " module is required for the 'lomb' method to run.",
             " Please install it first (`pip install astropy`).",
-        )
-    if normalize is True:
-        power /= np.max(power)
+        ) from e
 
     return frequency, power
 
@@ -256,7 +291,13 @@ def _signal_psd_lomb(
 
 
 def _signal_psd_burg(
-    signal, sampling_rate=1000, order=16, criteria="KIC", corrected=True, side="one-sided", normalize=True, nperseg=None
+    signal,
+    sampling_rate=1000,
+    order=16,
+    criteria="KIC",
+    corrected=True,
+    side="one-sided",
+    nperseg=None,
 ):
 
     nfft = int(nperseg * 2)
@@ -285,26 +326,21 @@ def _signal_psd_burg(
     #            w = w[1:]  # exclude first point (extra)
 
     frequency = (w * sampling_rate) / (2 * np.pi)
-    if normalize is True:
-        power /= np.max(power)
 
     return frequency, power
 
 
-
 def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
 
-
     # Sanitize order and signal
+    N = len(signal)
     if order <= 0.0:
         raise ValueError("Order must be > 0")
-    if order > len(signal):
+    if order > N:
         raise ValueError("Order must be less than length signal minus 2")
     if not isinstance(signal, np.ndarray):
         signal = np.array(signal)
 
-    N = len(signal)
-
     # Initialisation
     # rho is variance of driving white noise process (prediction error)
     rho = sum(abs(signal) ** 2.0) / float(N)
@@ -331,7 +367,9 @@ def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
 
         if criteria is not None:
             # k=k+1 because order goes from 1 to P whereas k starts at 0.
-            residual_new = _criteria(criteria=criteria, N=N, k=k + 1, rho=new_rho, corrected=corrected)
+            residual_new = _criteria(
+                criteria=criteria, N=N, k=k + 1, rho=new_rho, corrected=corrected
+            )
             if k == 0:
                 residual_old = 2.0 * abs(residual_new)
 
@@ -343,7 +381,9 @@ def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
             residual_old = residual_new
         rho = new_rho
         if rho <= 0:
-            raise ValueError("Found a negative value (expected positive strictly) %s." "Decrease the order" % rho)
+            raise ValueError(
+                f"Found a negative value (expected positive strictly) {rho}. Decrease the order."
+            )
 
         ar = np.resize(ar, ar.size + 1)
         ar[k] = kp
@@ -418,7 +458,9 @@ def _criteria(criteria=None, N=None, k=None, rho=None, corrected=True):
 
     elif criteria == "KIC":
         if corrected is True:
-            residual = np.log(rho) + k / N / (N - k) + (3.0 - (k + 2.0) / N) * (k + 1.0) / (N - k - 2.0)
+            residual = (
+                np.log(rho) + k / N / (N - k) + (3.0 - (k + 2.0) / N) * (k + 1.0) / (N - k - 2.0)
+            )
         else:
             residual = np.log(rho) + 3.0 * (k + 1.0) / float(N)
 
@@ -433,8 +475,9 @@ def _criteria(criteria=None, N=None, k=None, rho=None, corrected=True):
     return residual
 
 
-def _signal_psd_from_arma(ar=None, ma=None, rho=1., sampling_rate=1000, nfft=None, side="one-sided"):
-
+def _signal_psd_from_arma(
+    ar=None, ma=None, rho=1.0, sampling_rate=1000, nfft=None, side="one-sided"
+):
 
     if ar is None and ma is None:
         raise ValueError("Either AR or MA model must be provided")
