@@ -16,7 +16,7 @@ def signal_resample(
 
     Parameters
     ----------
-    signal :  list or array or Series
+    signal :  Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
     desired_length : int
         The desired length of the signal.
