@@ -1,5 +1,8 @@
 """Submodule for NeuroKit."""
 
+from .cluster import cluster
+from .cluster_findnumber import cluster_findnumber
+from .cluster_quality import cluster_quality
 from .correlation import cor
 from .density import density
 from .distance import distance
@@ -9,14 +12,9 @@ from .fit_mixture import fit_mixture
 from .fit_polynomial import fit_polynomial, fit_polynomial_findorder
 from .hdi import hdi
 from .mad import mad
-from .mutual_information import mutual_information
 from .rescale import rescale
 from .standardize import standardize
 from .summary import summary_plot
-from .cluster import cluster
-from .cluster_quality import cluster_quality
-from .cluster_findnumber import cluster_findnumber
-
 
 __all__ = [
     "standardize",
@@ -34,9 +32,8 @@ __all__ = [
     "fit_mse",
     "fit_rmse",
     "fit_r2",
-    "mutual_information",
     "summary_plot",
     "cluster",
     "cluster_quality",
-    "cluster_findnumber"
+    "cluster_findnumber",
 ]
