@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 import matplotlib.pyplot as plt
 import numpy as np
+import scipy.stats as st
 
 from .density import density
 from .rescale import rescale
 
 
-def summary_plot(x, **kwargs):
+def summary_plot(x, errorbars=0, **kwargs):
     """Descriptive plot.
 
     Visualize a distribution with density, histogram, boxplot and rugs plots all at once.
@@ -31,6 +32,10 @@ def summary_plot(x, **kwargs):
 
     # Histogram
     counts, bins = np.histogram(x, **kwargs)
+    bin_centers = 0.5*(bins[1:] + bins[:-1])
+    if errorbars > 0:
+        samperr = np.std(counts) / np.sqrt(counts) * (st.norm.ppf(1-(1-errorbars)/2))
+        ax.errorbar(bin_centers, counts, yerr=samperr, ecolor="#FF8C00", fmt='.', capsize=5, capthick=2)
     ax.hist(bins[:-1], bins, weights=counts, color="#2196F3", edgecolor="white", zorder=1, **kwargs)
 
     # Density
